# Generated by Django 3.2.25 on 2025-08-07 16:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('orchestra', '0098_auto_20230405_2000'),
    ]

    operations = [
        migrations.AlterField(
            model_name='staffingresponse',
            name='is_winner',
            field=models.BooleanField(null=True),
        ),
        migrations.AlterField(
            model_name='todoqa',
            name='approved',
            field=models.BooleanField(blank=True, null=True),
        ),
    ]



from rest_framework import routers
from django.conf.urls import include
from django.urls import re_path

from orchestra.project_api.views import assign_worker_to_task
from orchestra.project_api.views import create_project
from orchestra.project_api.views import project_details_url
from orchestra.project_api.views import project_information
from orchestra.project_api.views import workflow_types
from orchestra.project_api.views import message_project_team
from orchestra.project_api.views import TodoApiViewset
from orchestra.project_api.views import TodoTemplatesList
from orchestra.project_api.views import create_todos_from_template
from orchestra.views import TimeEntryDetail
from orchestra.views import TimeEntryList
from orchestra.views import dashboard_tasks
from orchestra.views import get_timer
from orchestra.views import save_task_assignment
from orchestra.views import start_timer
from orchestra.views import status
from orchestra.views import stop_timer
from orchestra.views import submit_task_assignment
from orchestra.views import task_assignment_information
from orchestra.views import update_timer
from orchestra.views import upload_image

app_name = 'api'

urlpatterns = [
    # Interface API
    re_path(r'^interface/dashboard_tasks/$',
            dashboard_tasks, name='dashboard_tasks'),

    re_path(r'^interface/task_assignment_information/$',
            task_assignment_information,
            name='task_assignment_information'),

    re_path(r'^interface/save_task_assignment/$',
            save_task_assignment,
            name='save_task_assignment'),

    re_path(r'^interface/submit_task_assignment/$',
            submit_task_assignment,
            name='submit_task_assignment'),

    re_path(r'^interface/upload_image/$',
            upload_image,
            name='upload_image'),

    re_path(r'^interface/time_entries/$',
            TimeEntryList.as_view(), name='time_entries'),

    re_path(r'^interface/time_entries/(?P<pk>[0-9]+)/$',
            TimeEntryDetail.as_view(), name='time_entry'),

    re_path(r'^interface/timer/start/$', start_timer, name='start_timer'),
    re_path(r'^interface/timer/stop/$', stop_timer, name='stop_timer'),
    re_path(r'^interface/timer/$', get_timer, name='get_timer'),
    re_path(r'^interface/timer/update/$', update_timer, name='update_timer'),

    re_path(r'^interface/project_management/',
            include('orchestra.interface_api.project_management.urls',
                    namespace='project_management')),

    # Client API
    re_path(r'^project/project_information/$',
            project_information,
            name='project_information'),
    re_path(r'^project/create_project/$',
            create_project,
            name='create_project'),
    re_path(r'^project/workflow_types/$',
            workflow_types,
            name='workflow_types'),
    re_path(r'^project/project_details_url/$',
            project_details_url,
            name='project_details_url'),
    re_path(r'^project/assign_worker_to_task/$',
            assign_worker_to_task,
            name='assign_worker_to_task'),
    re_path(r'^status/$',
            status,
            name='status'),
    re_path(r'^project/message_project_team',
            message_project_team,
            name='message_project_team'),
    re_path(r'^project/todo_templates/$',
            TodoTemplatesList.as_view(),
            name='todo_templates'),
    re_path(r'^project/create_todos_from_template/$',
            create_todos_from_template,
            name='create_todos_from_template'),
]

router = routers.SimpleRouter()
router.register(
    r'project/todo-api', TodoApiViewset, basename='todo-api'
)

urlpatterns += router.urls



from django.urls import re_path
from django.views.generic import RedirectView

from orchestra.accounts.views import AccountSettingsView
from orchestra.accounts.views import AvailabilitySettingsView
from orchestra.accounts.views import CommunicationPreferenceSettingsView
from orchestra.accounts.views import OrchestraRegistrationView

urlpatterns = [
    # We have to override the register endpoint to emit the
    # `orchestra_user_registered` signal
    re_path(r'^accounts/register/$',
            OrchestraRegistrationView.as_view(),
            name='registration_register'),
    re_path(r'^accounts/settings/$',
            AccountSettingsView.as_view(), name='account_settings'),
    re_path(r'^accounts/communication_preference_settings/$',
            CommunicationPreferenceSettingsView.as_view(),
            name='communication_preference_settings'),
    re_path(r'^accounts/availability_settings/$',
            AvailabilitySettingsView.as_view(),
            name='availability_settings'),
    re_path(r'^password/change/done/$',
            RedirectView.as_view(
                pattern_name='account_settings'),
            name='auth_password_change_done'),
]



from django.urls import re_path

from orchestra.communication.views import accept_staffing_request_inquiry
from orchestra.communication.views import available_staffing_requests
from orchestra.communication.views import reject_staffing_request_inquiry

app_name = 'communication'

urlpatterns = [
    # Interface API
    re_path(r'^accept_staffing_request_inquiry/(?P<staffing_request_inquiry_id>[0-9]+)/$',  # noqa
            accept_staffing_request_inquiry,
            name='accept_staffing_request_inquiry'),
    re_path(r'^reject_staffing_request_inquiry/(?P<staffing_request_inquiry_id>[0-9]+)/$',  # noqa
            reject_staffing_request_inquiry,
            name='reject_staffing_request_inquiry'),
    re_path(r'^available_staffing_requests/',
            available_staffing_requests,
            name='available_staffing_requests'),
]



from django.urls import re_path

from orchestra.interface_api.project_management import views

app_name = 'project_management'

urlpatterns = [
    re_path(r'^projects/$',
            views.ProjectList.as_view(),
            name='projects'),

    re_path(r'^assign_task/$',
            views.assign_task_api,
            name='assign_task'),

    re_path(r'^complete_and_skip_task/$',
            views.complete_and_skip_task_api,
            name='complete_and_skip_task'),

    re_path(r'^create_subsequent_tasks/$',
            views.create_subsequent_tasks_api,
            name='create_subsequent_tasks'),

    re_path(r'^edit_slack_membership/$',
            views.edit_slack_membership_api,
            name='edit_slack_membership'),

    re_path(r'^unarchive_slack_channel/$',
            views.unarchive_slack_channel_api,
            name='unarchive_slack_channel'),

    re_path(r'^end_project/$',
            views.end_project_api,
            name='end_project'),

    re_path(r'^set_project_status/$',
            views.set_project_status_api,
            name='set_project_status'),

    re_path(r'^project_information/$',
            views.project_information_api,
            name='project_information'),

    re_path(r'^reassign_assignment/$',
            views.reassign_assignment_api,
            name='reassign_assignment'),

    re_path(r'^revert_task/$',
            views.revert_task_api,
            name='revert_task'),

    re_path(r'^staff_task/$',
            views.staff_task,
            name='staff_task'),
]
